@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( IO::Async::Notifier );
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 our $DEFAULT_UA = "Perl + " . __PACKAGE__ . "/$VERSION";
 our $DEFAULT_MAXREDIR = 3;
@@ -55,7 +55,7 @@ use constant HTTPS_PORT => 443;
 use constant READ_LEN  => 64*1024; # 64 KiB
 use constant WRITE_LEN => 64*1024; # 64 KiB
 
-use Struct::Dumb;
+use Struct::Dumb 0.07;  # equallity operator overloading
 struct Ready => [qw( future connecting )];
 
 =head1 NAME
@@ -153,6 +153,17 @@ sub _init
    $self->{ssl_params} = {};
 }
 
+sub _remove_from_loop
+{
+   my $self = shift;
+
+   foreach my $conn ( map { @$_ } values %{ $self->{connections} } ) {
+      $conn->close;
+   }
+
+   $self->SUPER::_remove_from_loop( @_ );
+}
+
 =head1 PARAMETERS
 
 The following named parameters may be passed to C<new> or C<configure>:
